@@ -15,9 +15,13 @@ our $CFG = {
 };
 
 # CLI
-sub cli_name ($self) {
-    return 'nginx';
-}
+around CLI => sub ( $orig, $self ) {
+    my $cli = $self->$orig;
+
+    $cli->{name} = 'mysql';
+
+    return $cli;
+};
 
 # APP
 around _build_cfg => sub ( $orig, $self ) {
@@ -181,7 +185,7 @@ sub alien_proc ($self) {
 ## ┌──────┬──────────────────────┬────────────────────────────────────────────────────────────────────────────────────────────────────────────────┐
 ## │ Sev. │ Lines                │ Policy                                                                                                         │
 ## ╞══════╪══════════════════════╪════════════════════════════════════════════════════════════════════════════════════════════════════════════════╡
-## │    2 │ 140                  │ ValuesAndExpressions::ProhibitNoisyQuotes - Quotes used with a noisy string                                    │
+## │    2 │ 144                  │ ValuesAndExpressions::ProhibitNoisyQuotes - Quotes used with a noisy string                                    │
 ## └──────┴──────────────────────┴────────────────────────────────────────────────────────────────────────────────────────────────────────────────┘
 ##
 ## -----SOURCE FILTER LOG END-----
