@@ -1,6 +1,6 @@
 package Pcore::Handle::MySQL;
 
-use Pcore qw[-class];
+use Pcore -class;
 use DBD::mysql;
 
 with qw[Pcore::DBD];
