@@ -1,6 +1,6 @@
-package Pcore::MySQL v0.1.4;
+package Pcore::MySQL v0.2.0;
 
-use Pcore -class;
+use Pcore -dist, -class;
 
 1;
 __END__
